
# LinkedIn Job Scraper

A Python package to scrape job listings on LinkedIn for a specific job role and save the results to a CSV file.

## Installation 

To install LinkedIn Job Scraper, run the following command:
```pip install scrapeLinkedinJob```

## Contributing
Contributions to LinkedIn Job Scraper are welcome! To contribute, please follow these steps:

1. Fork this repository.
2. Create a new branch for your feature or bug fix.
3. Make your changes and commit them.
4. Push your changes to your fork.
5. Submit a pull request.

### This package is build by Sushil Dhakal